@@ -13,11 +13,9 @@ class CacheHTTPClient:
     version_salt = '1.0'
 
     def __init__(self):
-        base_url = (os.environ.get('ACTIONS_CACHE_URL', None) or os.environ.get('ACTIONS_RUNTIME_URL', None) or '').replace('pipelines', 'artifactcache')
-        assert base_url, "Cache Service Url not found, unable to restore cache."
-        self.base_url = base_url
         self.token = os.environ.get('ACTIONS_RUNTIME_TOKEN', '')
         self.version = os.environ.get('ACTIONS_CACHE_VERSION', '')
+        self.keys = os.environ.get('ACTIONS_CACHE_KEYS', '').split(',')
 
     def post_json(self, resource, body):
         response = urlopen(
@@ -35,13 +33,16 @@ class CacheHTTPClient:
         return json.load(response)
 
     def get_cache_api_url(self, resource):
-        return f"{self.base_url}_apis/artifactcache/{resource}"
+        base_url = (os.environ.get('ACTIONS_CACHE_URL', None) or os.environ.get('ACTIONS_RUNTIME_URL', None) or '').replace('pipelines', 'artifactcache')
+        assert base_url, "Cache Service Url not found, unable to restore cache."
+        return f"{base_url}_apis/artifactcache/{resource}"
 
     def get_cache_version(self, path):
         return hashlib.new('sha256', "|".join([path, self.version_salt, self.version]).encode()).hexdigest()
 
     def reserve_cache(self, key, path):
         version = self.get_cache_version(path)
+        key += '|' + self.keys[0]
         response = self.post_json('caches', {"key": key, "version": version})
         return response.get("cacheId", None) or -1
 
@@ -69,7 +70,8 @@ class CacheHTTPClient:
 
     def get_cache_entry(self, key, path):
         version = self.get_cache_version(path)
-        resource = 'cache?' + urlencode({"keys": key, "version": version})
+        keys = ",".join(f"{key}|{k}" for k in self.keys)
+        resource = 'cache?' + urlencode({"keys": keys, "version": version})
         response = urlopen(
             Request(
                 self.get_cache_api_url(resource),
