@@ -40,8 +40,8 @@ def task(format=None, retry=False):
             except Exception as e:
                 # e = e.with_traceback(e.__traceback__.tb_next.tb_next.tb_next)
                 if not runner.debug:
-                    e = e.with_traceback(None)
-                raise e
+                    raise e.with_traceback(None)
+                raise
 
         return wrapper
 
